# art-daq
Librería dedicada al uso de la tarjeta USB-6001. Se pretende que sea una librería de uso sencillo y accesible.  
Library dedicated to the use of the USB-6001 daq. It is intended to be a simple and accessible library.  
